summaryrefslogtreecommitdiff
path: root/libgphoto2/exif.h
diff options
context:
space:
mode:
authorHans Ulrich Niedermann <gp@n-dimensional.de>2005-06-11 21:10:45 +0000
committerHans Ulrich Niedermann <gp@n-dimensional.de>2005-06-11 21:10:45 +0000
commitab7a9d9373cbea75cd28ceecbeeb1e77b5de78a2 (patch)
treea964ccc95a41c245a453be775ce1248694e702fc /libgphoto2/exif.h
parent9abc6a8c05448ffb7d6b4e7f0dd0505f6d31931d (diff)
downloadlibgphoto2-ab7a9d9373cbea75cd28ceecbeeb1e77b5de78a2.tar.gz
namespace cleanup still going on:
- Add comments to Makefile.am about the different symbol names and their purposes, so that the rationale behind the *.sym contents may be found easily. - Remove libgphoto2/pattrec.[ch] - the only user was camlibs/konica/qm150.c and it hasn't been using it probably for years. - Rename all formerly exported symbols not starting with gp_* to gpi_* or gpe_* and try to export only those which are absolutely required by the camlibs. This still leaves a number of internal symbols exported, but at least their number is a lot lower than it was before. git-svn-id: https://svn.code.sf.net/p/gphoto/code/trunk/libgphoto2@8073 67ed7778-7388-44ab-90cf-0a291f65f57c
Diffstat (limited to 'libgphoto2/exif.h')
-rw-r--r--libgphoto2/exif.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libgphoto2/exif.h b/libgphoto2/exif.h
index ddf4c29f1..0bb454e19 100644
--- a/libgphoto2/exif.h
+++ b/libgphoto2/exif.h
@@ -67,34 +67,34 @@ int exif_parse_data(exifparser *exifdat);
/*
* Returns the value of a field, identified by its tag and the IFD.
*/
-int exif_get_field( int tag_number, int ifd, exifparser *exifdat, ExifData *tag_data);
+int gpi_exif_get_field( int tag_number, int ifd, exifparser *exifdat, ExifData *tag_data);
/*
* Gets a numeric tag
*/
-int exif_get_int_field( int tag_number, int ifd, exifparser *exifdat);
+int gpi_exif_get_int_field( int tag_number, int ifd, exifparser *exifdat);
/*
* Gets an ASCII tag.
*/
-char * exif_get_ascii_field( int tag_number, int ifd, exifparser *exifdat);
+char * gpi_exif_get_ascii_field( int tag_number, int ifd, exifparser *exifdat);
/*
* Returns the name of a given tag number
*/
-char *exif_get_tagname(int tag_number);
+char *gpi_exif_get_tagname(int tag_number);
/*
* Returns a pointer to the thumbnail data if it
* exists.
*/
-unsigned char *exif_get_thumbnail(exifparser *exifdat);
+unsigned char *gpi_exif_get_thumbnail(exifparser *exifdat);
/*
* The same as exif_get_thumbnail but returns
* also the thumbnail size
*/
-unsigned char *exif_get_thumbnail_and_size(exifparser *exifdat, long *size);
+unsigned char *gpi_exif_get_thumbnail_and_size(exifparser *exifdat, long *size);
/*
* Gets the comment field if it exists.
@@ -109,7 +109,7 @@ int gpe_set_comment(exifparser *exifdat, char *comment);
/*
* COMMENT ME
*/
-int stat_exif(exifparser *exifdata);
+int gpi_exif_stat(exifparser *exifdata);
int gpe_dump_exif(exifparser *exifdata);
/*
@@ -67,34 +67,34 @@ int exif_parse_data(exifparser *exifdat);
/*
- * The same as exif_get_thumbnail but returns
+ * The same as gpi_exif_get_thumbnail but returns
* also the thumbnail size
*/